@@ -5,6 +5,7 @@ from pypsql_api.wire.actions_types import Names
 from pypsql_api.context import Context
 from pypsql_api.wire.back import SSLNo, AuthenticationCleartextPassword, ReadyForQuery, AuthenticationOk, \
     EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete
+from pypsql_api.wire.errors import NoData
 from pypsql_api.wire.front import SSLRequest, StartupMessage, Message, PasswordMessage
 
 
@@ -32,6 +33,9 @@ def read_startup_message(context: Context):
 
         context.session = session
         return context.update_mem('session', session), Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST
+    except NoData as e:
+        print(f"No data received from server")
+        return context, Names.CLOSE
     except:
         print(f"Error udring startup read")
         traceback.print_exc()
