@@ -37,7 +37,8 @@ processes = {
     Names.READ_SSL_REQUEST: State(name=Names.READ_SSL_REQUEST, allowed={Names.WRITE_SSL_NO}, fn=read_ssl_request),
     Names.WRITE_SSL_NO: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE}, fn=write_ssl_resp_no),
     Names.READ_STARTUP_MESSAGE: State(name=Names.READ_STARTUP_MESSAGE,
-                                      allowed={Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST}, fn=read_startup_message),
+                                      allowed={Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST, Names.CLOSE,
+                                               Names.READ_STARTUP_MESSAGE}, fn=read_startup_message),
 
     Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST: State(name=Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST,
                                                    allowed={Names.READ_PLAIN_TEXT_PASSWORD},
@@ -107,7 +108,8 @@ processes = {
 
     Names.DESCRIBE: State(name=Names.DESCRIBE,
                           allowed={Names.CLOSE, Names.SYNC,
-                                   Names.WRITE_EXTENDED_DATA_FRAME, Names.WRITE_EXTENDED_EMPTY_RESPONSE, Names.RECEIVE_EXTENDED_QUERY_COMMAND},
+                                   Names.WRITE_EXTENDED_DATA_FRAME, Names.WRITE_EXTENDED_EMPTY_RESPONSE,
+                                   Names.RECEIVE_EXTENDED_QUERY_COMMAND},
                           fn=describe_statement_or_portal),
 
     Names.RECEIVE_EXTENDED_QUERY_COMMAND: State(name=Names.RECEIVE_EXTENDED_QUERY_COMMAND,
